package main;

import javafx.scene.Scene;
import javafx.stage.Stage;
import main.select_candidate_name.SelectCandidateNameLoader;
import main.straight_channel_section.StraightChannelSectionLoader;
import main.welcome_splash.WelcomeSplashLoader;

import java.io.IOException;

/**
 * Created by Vladimir Eliezer Tokarev on 8/27/2016.
 * ChainBuilder builds all the two way nodes that are in current project (voting-booth-gui)
 *              and connects between all of them so they can keep their flow
 */
public class ChainBuilder {

    /**
     * Creates all  the twoWayNodes and connects between them
     *
     * The flow of Voting booth gui is next
     *      Welcome Splash screen
     *                \/
     *      Channel selection screen
     *                \/
     *      Select Candidate Name screen
     *         \/            /\
     *      Select candidate by picture screen
     *         \/            /\
     *      Ballot summary no pictures
     *                \/
     *      Cast Or audit screen
     *                \/
     *      thank you for screen
     * In order to maintain this order next technique was implemented every "screen" will have the next screen
     * and the previous this way the flow between will be easy .
     * The Build method creates all the screens and connect between them
     */
    public static void Build(Stage primaryStage) throws IOException {
        WelcomeSplashLoader welcomeSplashLoader = new WelcomeSplashLoader(primaryStage);
        TwoWayNode welcomeSplashController = welcomeSplashLoader.GetWelcomeSplash();

        StraightChannelSectionLoader straightChannelSectionLoader = new StraightChannelSectionLoader(primaryStage);
        TwoWayNode straightChannelSectionController = straightChannelSectionLoader.GetStraightChannelSection();
        welcomeSplashController.SetNext(straightChannelSectionController);
        straightChannelSectionController.SetPrevious(welcomeSplashController);

        SelectCandidateNameLoader selectCandidateNameLoader = new SelectCandidateNameLoader(primaryStage);
        TwoWayNode selectCandidateNameController = selectCandidateNameLoader.GetSelectCandidateName();
        selectCandidateNameController.SetPrevious(straightChannelSectionController);
        straightChannelSectionController.SetNext(selectCandidateNameController);



        /**
         * all other two way nodes initialized
         */

        primaryStage.setScene(welcomeSplashController.GetNode());
    }
}
